@@ -55,6 +55,8 @@ pwd = "1"
 
 name_cache = {}
 
+remark_about_missing_module_info = set()
+
 
 class NotInAddonsPath(Exception):
     pass
@@ -708,7 +710,7 @@ class Modules(object):
             modules[m.parent.name] = module
 
         for module in modules.values():
-            Modules._get_module_dependency_tree(modules, module)
+            Modules._get_module_dependency_tree(list(modules.values()), module)
 
         # if directory is clear, we may cache
         return modules
@@ -778,25 +780,26 @@ class Modules(object):
             data[mod.name] = {}
             if depth > 1000:
                 raise Exception("Recursive loop perhaps - to depth")
-            for dep in mod.manifest_dict.get("depends", []):
+            for dep in list(mod.manifest_dict.get("depends", [])):
                 if dep == "base":
                     data[mod.name][dep] = {}
                     continue
-                dep_mod = [x for x in modules.values() if x.name == dep]
+                dep_mod = [x for x in modules if x.name == dep]
                 try:
                     dep_mod = dep_mod[0]
                 except IndexError:
                     # if it is a module, which is probably just auto install
                     # but not in the manifest, then it is not critical
-                    click.secho(
-                        (
-                            f"Module not found at resolving dependencies: {dep}"
-                            f". Not necessarily a problem at auto install modules."
-                            "\n\n\n"
-                        ),
-                        fg="yellow",
-                        bold=True,
-                    )
+                    if dep not in remark_about_missing_module_info:
+                        remark_about_missing_module_info.add(dep)
+                        click.secho(
+                            (
+                                f"Module not found at resolving dependencies: {dep}"
+                                ". Not necessarily a problem at auto install modules."
+                            ),
+                            fg="yellow",
+                            bold=True,
+                        )
                 else:
                     data[mod.name][dep] = {}
                     append_deps(dep_mod, data[mod.name][dep], depth=depth + 1)
@@ -806,9 +809,9 @@ class Modules(object):
             module._dep_tree = result
         return module._dep_tree
 
-    def get_all_modules_installed_by_manifest(self):
+    def get_all_modules_installed_by_manifest(self, additional_modules=None):
         all_modules = set()
-        for module in MANIFEST().get("install", []):
+        for module in MANIFEST().get("install", []) + (additional_modules or []):
             all_modules.add(module)
             module = Module.get_by_name(module)
             for module2 in self.get_module_flat_dependency_tree(module):
